@@ -92,7 +92,11 @@ DEET_enrich <- function(DEG_list, DEET_dataset, ordered = FALSE, background = NU
     rownames(mat) <- genes_cor
 
     # Populate input fold-change.
-    mat$input <- DEG_processed[DEG_processed$gene_symbol %in% genes_cor, ]$coef
+    DEG_processed1 <- DEG_processed[DEG_processed$gene_symbol %in% genes_cor, ]
+    DEG_processed1 <- DEG_processed1[genes_cor,]
+    mat$input <- DEG_processed1$coef
+    
+    #mat$input <- DEG_processed[DEG_processed$gene_symbol %in% genes_cor, ]$coef
 
     # Populate DEET fold-change.
     mat$DEET <- comp[genes_cor, ]$log2FoldChange
@@ -300,9 +304,9 @@ DEET_enrich <- function(DEG_list, DEET_dataset, ordered = FALSE, background = NU
   
   # If nothing was enirched at this point
   if(sum(nrow(AP_DEET_DE_sig), nrow(AP_INPUT_BP_output), nrow(AP_INPUT_TF_output)) == 0) {
-    warning("Basic pathway enrichment and DEET all yeiled0 signficant pathwys, TF motifs, and studies. Check input if you think there should be some enrichment.")
+    warning("Basic pathway enrichment and DEET all yieled 0 signficant pathways, TF motifs, and studies. Check input if you think there should be some enrichment.")
 
-    return("Basic pathway enrichment and DEET all yeiled0 signficant pathwys, TF motifs, and studies. Check input if you think there should be some enrichment.")
+    return("Basic pathway enrichment and DEET all yieled 0 signficant pathways, TF motifs, and studies. Check input if you think there should be some enrichment.")
   }
 
   # If nothing is enriched -- return that statement
@@ -422,11 +426,11 @@ DEET_enrich <- function(DEG_list, DEET_dataset, ordered = FALSE, background = NU
       cor_mats <- lapply(tst, function(x) return (x$matrix))
 
       # Make sure that correlations are significant with Pearson or Spearman.
-      cor_results_sig <- cor_results[cor_results$FDR_Pear < 0.05 |
-                                       cor_results$FDR_Spear < 0.05, ]
+      cor_results_sig <- cor_results[cor_results$FDR_Pear < 0.1 |
+                                       cor_results$FDR_Spear < 0.1, ]
 
-      cor_mats_sig <- cor_mats[cor_results$FDR_Pear < 0.05 |
-                                 cor_results$FDR_Spear < 0.05]
+      cor_mats_sig <- cor_mats[cor_results$FDR_Pear < 0.1 |
+                                 cor_results$FDR_Spear < 0.1]
 
       rownames(cor_results_sig) <- cor_results_sig$DEET.ID
       names(cor_mats_sig) <- cor_results_sig$DEET.ID
